kpath — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# kpath

pyprocar.scripts.kpath(infile=None, outfile='KPOINTS', grid_size=40, with_time_reversal=True, recipe='hpkot', threshold=1e-07, symprec=1e-05, angle_tolerence=-1.0, supercell_matrix=array([[1., 0., 0.], [0., 1., 0.], [0., 0., 1.]]))

  This module creates a KPOINTS file for band structure plotting.

  Parameters:

    - infile (str, optional)

    - outfile (str, optional)

    - grid_size (int, optional)

    - with_time_reversal (bool, optional)

    - recepie (str, optional)

    - threshold (float, optional)

    - symprec (float, optional)

    - angle_tolerence (float, optional)

    - supercell_matrix (list, int)